@@ -17,23 +17,34 @@ HTML::Auto - The great new HTML::Auto!
 
 =head1 VERSION
 
-Version 0.01_1
+Version 0.01_2
 
 =cut
 
-our $VERSION = '0.01_1';
+our $VERSION = '0.01_2';
 
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
+Simple example:
 
-Perhaps a little code snippet.
+  use HTML::Auto qw/matrix h v/;
 
-    use HTML::Auto;
+  my @cols = qw/c1 c2 c3 c4 c5/;
+  my @lines = qw/l1 l2 l3 l4 l5/;
+  my $data =
+     [ [1,2,3,4,5],
+       [6,7,8,9,0],
+       [1,1,1,1,1],
+       [2,2,2,2,2],
+       [3,3,3,3,3] ];
 
-    my $foo = HTML::Auto->new();
-    ...
+  my $m = matrix(\@cols,\@lines,$data);
+
+  print v(
+          h($m,$m,$m),
+          h($m,$m),
+        );
 
 =head1 SUBROUTINES/METHODS
 
